@@ -2,9 +2,8 @@ package Catalyst::TraitFor::Model::DBIC::Schema::ConnectInfo::Several;
 
 use namespace::autoclean;
 use Moose::Role;
-use MooseX::Types::Moose qw/ Str HashRef /;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 =head1 NAME
 
@@ -28,7 +27,7 @@ for several C<connect_info> entries.
             traits            => ['ConnectInfo::Several'],
             schema_class      => 'MyApp::Schema',
             active_connection => 'mysql_devel',
-            connection      => {
+            connections       => {
                 mysql_devel       => [ 'dbi:mysql:db_devel', 'user1', 'pass1' ],
                 mysql_production  => [ 'dbi:mysql:db_prod',  'user2', 'pass2' ],
             },
@@ -41,7 +40,7 @@ for several C<connect_info> entries.
     <Model::DB>
         traits                  ConnectInfo::Several
         active_connection       mysql_devel
-        <connection>
+        <connections>
             <mysql_devel>
                 dns             dbi:mysql:db_devel
                 user            user1
@@ -52,41 +51,31 @@ for several C<connect_info> entries.
                 user            user2
                 password        pass2
             </mysql_prod>
-        </connection>
+        </connections>
     </Model::DB>
 
 =head1 DESCRIPTION
 
-You can define several named connections in C<connection> hash, and selectr
-which one should be used currently with C<active_connection>. You shouldn't
-define C<connect_info>, it will be set for you, depending on what you set
-in C<active_connection> and C<connection>.
-Also, set C<AutoCommit> option for you to C<1>, if you don't set it yet.
+You can define several connections in C<connections> hash, and select
+which one should be used currently via C<active_connection>. You shouldn't
+define C<connect_info> - it will be set for you, depending on what you set
+in C<active_connection> and C<connections>.
 
 This trait will do something only if you set C<active_connection>, otherwise
 it just do nothing, like it was not used at all.
 
 =cut
 
-has 'active_connection' => (
-    is  => 'ro',
-    isa => 'Str',
-);
-
-has 'connection' => (
-    is  => 'ro',
-    isa => 'HashRef',
-);
-
 around 'BUILDARGS' => sub {
     my $orig  = shift;
     my $class = shift;
 
     my $new = $class->$orig(@_);
 
-    if ( exists( $new->{active_connection} ) && exists( $new->{connection}->{ $new->{active_connection} } ) ) {
-        $new->{connect_info} = $new->{connection}->{ $new->{active_connection} };
-        $new->{connect_info}->{AutoCommit} = 1 unless exists( $new->{connect_info}->{AutoCommit} );
+    if ( exists( $new->{active_connection} ) && exists( $new->{connections}->{ $new->{active_connection} } ) ) {
+        $new->{connect_info} = $new->{connections}->{ $new->{active_connection} };
+        delete $new->{active_connection};
+        delete $new->{connections};
     }
 
     return $new;
@@ -106,13 +95,11 @@ L<Catalyst::Model::DBIC::Schema>, L<DBIx::Class>, L<Catalyst>
 
 =item * Report bugs or feature requests
 
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Catalyst-TraitFor-Model-DBIC-Schema-ConnectInfo-Several>
-
-L<http://www.assembla.com/spaces/Catalyst-TraitFor-Model-DBIC-Schema-ConnectInfo-Several/tickets>
+    L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Catalyst-TraitFor-Model-DBIC-Schema-ConnectInfo-Several>
 
 =item * Git repository
 
-git clone git://git.assembla.com/Catalyst-TraitFor-Model-DBIC-Schema-ConnectInfo-Several.git
+    git clone git://github.com/cub-uanic/Catalyst-TraitFor-Model-DBIC-Schema-ConnectInfo-Several.git
 
 =back
 
